@@ -9,6 +9,7 @@
 
 #include "videoframe.h"
 #include <QString>
+#include <QImageIOHandler>
 
 extern "C" {
 #include <libavcodec/avcodec.h>
@@ -40,6 +41,8 @@ public:
     void destroy();
     bool getInitialized();
 
+    QImageIOHandler::Transformations transformations();
+
 private:
     bool initializeVideo();
 
